@@ -1,3 +1,4 @@
+import pickle
 from functools import reduce
 from pathlib import Path
 
@@ -64,6 +65,10 @@ def scriptcsv(container: Model, rootdir: Path):
 
     container.trace.summary.to_csv(rootdir / 'footprint_performance.csv')
 
+    model_file = rootdir / 'model.pkl'
+    with model_file.open('wb') as f:
+        pickle.dump(container, f)
+
 
 def save_footprint(footprint: FootprintOutput, rootdir: Path, name: str, suffix='good'):
     """
